@@ -1,19 +1,20 @@
 package Locale::CLDR::Locales::En::Any;
 
 # This file auto generated
-#	on Sat 24 Oct  9:30:18 am GMT
+#	on Sun 16 Dec  4:13:26 pm GMT
 
 use version;
 
-our $VERSION = version->declare('v0.28.1');
+our $VERSION = version->declare('v0.34.0');
 
 use v5.10.1;
 use mro 'c3';
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
-use Moose;
+use Moo;
 
 extends('Locale::CLDR::Locales::En');
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
+
+1;
